import { EChartsInitOpts, EChartsOption, ResizeOpts, SetOptionOpts } from 'echarts';
import { init } from 'echarts/core';
import { ECBasicOption } from 'echarts/types/dist/shared';
import { ReadableStream } from 'web-streams-polyfill';
import { CustomElement } from 'web-utility';
import { ProxyElement } from '../Proxy';
import { StreamRequest, ZRElementEventHandler, ZRElementEventName } from '../utility';
export type EChartsElementEventHandler = Partial<Record<`on${Capitalize<ZRElementEventName>}`, ZRElementEventHandler>>;
export interface EChartsElementProps extends ECBasicOption, EChartsElementEventHandler {
    theme?: Parameters<typeof init>[1];
    initOptions?: Omit<EChartsInitOpts, 'renderer'>;
    setOptions?: SetOptionOpts;
    resizeOptions?: ResizeOpts;
}
export type EChartsElementState = EChartsElementProps & EChartsOption;
export declare abstract class EChartsElement extends ProxyElement<EChartsElementState> implements CustomElement {
    #private;
    get renderer(): EChartsInitOpts["renderer"];
    get options(): ECBasicOption;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    setOption: ((input_0: EChartsOption) => Promise<void>) & {
        stream: ReadableStream<StreamRequest<[EChartsOption], void>>;
    };
    setProperty(key: string, value: any): void;
    protected processStream<I extends any[], O = void>(stream: ReadableStream<StreamRequest<I>>, executor: (...input: I) => O, context?: object): Promise<void>;
    protected connectChildStream<I extends any[], O = void>(executor: (...input: I) => O): (stream: ReadableStream<StreamRequest<I>>) => Promise<void>;
    connectOption: (stream: ReadableStream<StreamRequest<[option: EChartsOption], void>>) => Promise<void>;
    connectAddListener: (stream: ReadableStream<StreamRequest<[event: string, selector: string, handler: ZRElementEventHandler], void>>) => Promise<void>;
    connectRemoveListener: (stream: ReadableStream<StreamRequest<[event: string, handler: ZRElementEventHandler], void>>) => Promise<void>;
    addEventListener: ((input_0: string, input_1: EventListener) => Promise<void>) & {
        stream: ReadableStream<StreamRequest<[string, EventListener], void>>;
    };
    removeEventListener: ((input_0: string, input_1: EventListener) => Promise<void>) & {
        stream: ReadableStream<StreamRequest<[string, EventListener], void>>;
    };
    handleResize: import("lodash").DebouncedFunc<() => void>;
}
